%bcond_with texlive

%global octave_api api-v58
%global blaslib flexiblas
%global build_ldflags %{build_ldflags} -flto

Summary:        A high-level language for numerical computations
Name:           octave
Version:        8.2.0
Release:        8%{?dist}
License:        GPLv3+
URL:            http://www.octave.org
Source0:        https://ftp.gnu.org/gnu/octave/octave-%{version}.tar.lz
Source1:        macros.octave
Source2:        xorg.conf
Source3:        octave-config-%{version}
Source4:        mkoctfile-%{version}

Patch3000:      octave-time.patch

BuildRequires: lzip automake libtool desktop-file-utils libappstream-glib arpack-devel %{blaslib}-devel bison
BuildRequires: bzip2-devel curl-devel fftw-devel flex fltk-devel ftgl-devel gcc-c++ gcc-gfortran ghostscript
BuildRequires: gl2ps-devel glpk-devel gnuplot gperf GraphicsMagick-c++-devel hdf5-devel java-devel
BuildRequires: javapackages-local less libsndfile-devel libX11-devel llvm-devel mesa-libGL-devel mesa-libGLU-devel
BuildRequires: mesa-libOSMesa-devel ncurses-devel pcre2-devel portaudio-devel qhull-devel qrupdate-devel
BuildRequires: qt5-linguist qt5-qttools-devel rapidjson-devel readline-devel texinfo sundials-devel zlib-devel
BuildRequires: mesa-dri-drivers xorg-x11-drv-dummy zip make suitesparse-devel
%if %{with texlive}
BuildRequires:  tex(dvips) texinfo-tex texlive-collection-fontsrecommended texlive-ec texlive-metapost
%endif
Requires: epstool gnuplot gnuplot-common hdf5 hicolor-icon-theme java-headless less info texinfo
%if %{with texlive}
Requires: tex(amssymb.sty) tex(fontenc.sty) tex(graphicx.sty) tex(hyperref.sty) tex(inputenc.sty)
Requires: tex(listings.sty) tex(lmodern.sty) tex(mathtools.sty) tex(titlesec.sty) tex(xcolor.sty)
Requires: tex(color.sty) tex(epsfig.sty) tex(geometry.sty) tex(graphicx.sty)
%endif
Provides:       %{name}-doc = %{version}-%{release}
Provides:       octave(api) = %{octave_api}
Provides:       bundled(gnulib)
Provides:       bundled(qterminal)
Provides:       bundled(amos)
Provides:       bundled(blas-xtra)
Provides:       bundled(daspk)
Provides:       bundled(dasrt)
Provides:       bundled(dassl)
Provides:       bundled(faddeeva)
Provides:       bundled(lapack-xtra)
Provides:       bundled(odepack)
Provides:       bundled(ordered-qz)
Provides:       bundled(quadpack)
Provides:       bundled(ranlib)
Provides:       bundled(slatec-err)
Provides:       bundled(slatec-fn)

%description
GNU Octave is a high-level language, primarily intended for numerical computations. It provides a
convenient command line interface for solving linear and nonlinear problems numerically, and for
performing other numerical experiments using a language that is mostly compatible with Matlab. It
may also be used as a batch-oriented language. Octave has extensive tools for solving common
numerical linear algebra problems, finding the roots of nonlinear equations, integrating ordinary
functions, manipulating polynomials, and integrating ordinary differential and
differential-algebraic equations. It is easily extensible and customizable via user-defined
functions written in Octave's own language, or using dynamically loaded modules written in C++, C,
Fortran, or other languages.

%package devel
Summary:        Development headers and files for Octave
Requires:       %{name} = %{version}-%{release} gcc-c++ gcc-gfortran fftw-devel hdf5-devel %{blaslib}-devel
Requires:       readline-devel zlib-devel libappstream-glib

%description devel
The octave-devel package contains files needed for developing applications which use GNU Octave.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
export AR=%{_bindir}/gcc-ar
export RANLIB=%{_bindir}/gcc-ranlib
export NM=%{_bindir}/gcc-nm
export F77=gfortran
libjvm=$(find /usr/lib/jvm/jre/lib -name libjvm.so -printf %h)
export JAVA_HOME=%{java_home}
export CPPFLAGS=-I%{_includedir}/suitesparse
export CXXFLAGS="$(echo %optflags | sed s/-Wp,-D_GLIBCXX_ASSERTIONS//)"

verstr=$(%{__cxx} --version | head -1)
if [[ "$verstr" == *"GCC"* ]]; then
  CXXFLAGS="$CXXFLAGS -flto=auto"
else
  CXXFLAGS="$CXXFLAGS -flto"
fi

%configure --enable-shared --disable-static \
 --enable-float-truncate \
 --disable-silent-rules \
 --with-blas=%{blaslib}%{?with_blas64:64}  \
 --with-java-includedir=/usr/lib/jvm/java/include \
 --with-java-libdir=$libjvm \
 --with-qrupdate \
 --with-amd --with-umfpack --with-colamd --with-ccolamd --with-cholmod \
 --with-cxsparse \
 --disable-jit

make liboctave/version.h
if ! grep -q '^#define OCTAVE_API_VERSION "%{octave_api}"' liboctave/version.h
then
  echo "octave_api variable in spec does not match liboctave/version.h"
  exit 1
fi

%make_build OCTAVE_RELEASE="%{_vendor} %{version}-%{release}"

%install
%make_install

make install-data install-html install-info install-pdf DESTDIR=%{buildroot}
mkdir -p %{buildroot}%{_pkgdocdir}
cp -ar AUTHORS BUGS ChangeLog examples NEWS README %{buildroot}%{_pkgdocdir}/
cp -a doc/refcard/*.pdf %{buildroot}%{_pkgdocdir}/

find %{buildroot}%{_libdir} -name \*.la -delete

rm -f %{buildroot}%{_infodir}/dir

mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo "%{_libdir}/octave/%{version}" > %{buildroot}%{_sysconfdir}/ld.so.conf.d/octave-%{_arch}.conf

perl -pi -e "s,%{buildroot},," %{buildroot}%{_libdir}/%{name}/ls-R
perl -pi -e "s,%{buildroot},," %{buildroot}%{_datadir}/%{name}/ls-R
touch %{buildroot}%{_datadir}/%{name}/ls-R

desktop-file-validate %{buildroot}%{_datadir}/applications/org.octave.Octave.desktop
%{?el7:sed -i -e /project_group/d %{buildroot}/%{_datadir}/metainfo/org.octave.Octave.appdata.xml}
appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/metainfo/org.octave.Octave.appdata.xml

HOST_TYPE=`%{buildroot}%{_bindir}/octave-config -p CANONICAL_HOST_TYPE`
mkdir -p %{buildroot}%{_libdir}/%{name}/site/oct/%{octave_api}/$HOST_TYPE
mkdir -p %{buildroot}%{_libdir}/%{name}/site/oct/$HOST_TYPE
mkdir -p %{buildroot}%{_datadir}/%{name}/packages
mkdir -p %{buildroot}%{_libdir}/%{name}/packages
touch %{buildroot}%{_datadir}/%{name}/octave_packages

for script in octave-config-%{version} mkoctfile-%{version}
do
   mv %{buildroot}%{_bindir}/${script} %{buildroot}%{_libdir}/%{name}/%{version}/${script}
done
cp %{SOURCE3} %{SOURCE4} %{buildroot}%{_bindir}/

sed -i -e '/^# Created by Octave/d' %{buildroot}%{_datadir}/%{name}/%{version}/etc/doc-cache

mkdir -p %{buildroot}%{_rpmconfigdir}/macros.d
cp -p %SOURCE1 %{buildroot}%{_rpmconfigdir}/macros.d

%check
cp %SOURCE2 .
/usr/libexec/Xorg -noreset +extension GLX +extension RANDR +extension RENDER -logfile ./xorg.log -config ./xorg.conf :99 &
sleep 2
export DISPLAY=:99
export FLEXIBLAS=netlib
%ifarch ppc64le
make check || :
%else
make check
%endif

%files
%license COPYING
%dir %{_pkgdocdir}
%{_pkgdocdir}/AUTHORS
%{_pkgdocdir}/BUGS
%{_pkgdocdir}/ChangeLog
%{_pkgdocdir}/NEWS
%{_pkgdocdir}/README
%{_pkgdocdir}/examples/
%{_pkgdocdir}/liboctave.html/
%{_pkgdocdir}/liboctave.pdf
%{_pkgdocdir}/octave.html
%{_pkgdocdir}/octave.pdf
%{_pkgdocdir}/refcard*.pdf
%config(noreplace) %{_sysconfdir}/ld.so.conf.d/octave-*.conf
%{_bindir}/octave*
%dir %{_libdir}/octave/
%dir %{_libdir}/octave/%{version}
%{_libdir}/octave/%{version}/liboctave.so.10*
%{_libdir}/octave/%{version}/liboctgui.so.9*
%{_libdir}/octave/%{version}/liboctinterp.so.11*
%{_libdir}/octave/%{version}/mkoctfile-%{version}
%{_libdir}/octave/%{version}/oct/
%{_libdir}/octave/%{version}/octave-config-%{version}
%{_libdir}/octave/%{version}/site/
%{_libdir}/octave/packages/
%{_libdir}/octave/site/
%{_libexecdir}/octave/
%{_infodir}/liboctave.info*
%{_infodir}/octave.info*
%{_datadir}/applications/org.octave.Octave.desktop
%{_datadir}/icons/hicolor/*/apps/octave.png
%{_datadir}/icons/hicolor/scalable/apps/octave.svg
%{_datadir}/metainfo/org.octave.Octave.appdata.xml
%dir %{_datadir}/octave
%{_datadir}/octave/%{version}/
%{_datadir}/octave/ls-R
%ghost %{_datadir}/octave/octave_packages
%{_datadir}/octave/packages/
%{_datadir}/octave/site/
%{_mandir}/man1/octave*.1.*

%files devel
%{_rpmconfigdir}/macros.d/macros.octave
%{_bindir}/mkoctfile
%{_bindir}/mkoctfile-%{version}
%{_includedir}/octave-%{version}/
%{_libdir}/octave/%{version}/liboctave.so
%{_libdir}/octave/%{version}/liboctgui.so
%{_libdir}/octave/%{version}/liboctinterp.so
%{_libdir}/pkgconfig/octave.pc
%{_libdir}/pkgconfig/octinterp.pc
%{_mandir}/man1/mkoctfile.1.*

%changelog
* Mon Dec 25 2023 luffyluo <luffyluo@tencent.com> - 8.2.0-8
- Rebuilt for llvm 17.0.6

* Mon Nov 13 2023 cunshunxia@tencent.com - 8.2.0-7
- Rebuilt for libsndfile 1.2.0-4

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 8.2.0-6
- Rebuild for curl-8.4.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.2.0-5
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Sep 04 2023 cunshunxia <cunshunxia@tencent.com> - 8.2.0-4
- Rebuilt for ghostscript 10.01.2

* Wed Aug 23 2023 cunshunxia <cunshunxia@tencent.com> - 8.2.0-3
- Rebuilt for qhull 8.0.2

* Mon May 8 2023 Shuo Wang <abushwang@tencent.com> - 8.2.0-2
- update macros.octave

* Tue Apr 18 2023 Shuo Wang <abushwang@tencent.com> - 8.2.0-1
- initial build
